@@ -16,7 +16,9 @@ from .azure_sql import (
     AzureSQLCreateTable,
     AzureSQLDBQuery,
     CreateTableFromBlob,
+    AzureSQLToDF,
     CheckColumnOrder,
+    AzureSQLUpsert,
 )
 from .bcp import BCPTask
 from .github import DownloadGitHubFile
@@ -25,10 +27,13 @@ from .sqlite import SQLiteInsert, SQLiteSQLtoDF, SQLiteQuery
 from .supermetrics import SupermetricsToCSV, SupermetricsToDF
 from .sharepoint import SharepointToDF
 from .cloud_for_customers import C4CReportToDF, C4CToDF
+from .prefect import GetFlowNewDateRange
+from .aselite import ASELiteToDF
 
 try:
     from .sap_rfc import SAPRFCToDF
 except ImportError:
     pass
 
-from .duckdb import DuckDBCreateTableFromParquet, DuckDBQuery
+from .duckdb import DuckDBCreateTableFromParquet, DuckDBQuery, DuckDBToDF
+from .sql_server import SQLServerCreateTable
